/**************************************************************************************************/

/*
 * File: list.h
 * Author: Roman Lysecky
 * Date Created: 18 September 2012
 *
 * Description: Declaration of a singly-linked list containing dynamically allocated strings.
 *
 * Copyright: Roman Lysecky, Electrical and Computer Engineering, University of Arizona, 2012.
 *
 */

/**************************************************************************************************/

#include "bool.h"
#include "listelmt.h"

/**************************************************************************************************/

#ifndef LIST_H
#define LIST_H

/**************************************************************************************************/

typedef struct List_ {
   ListElmt *head;
   ListElmt *tail;
   int size;
} List;

/**************************************************************************************************/

/* initialize list to empty list */
void list_init(List* list);

/*
 * destroys the list by freeing all memory allocated for each line element returning the list
 * to an empty list
 */
void list_destroy(List * list);

/*
 * inserts new string into list after the given list element
 * location. If the list element location is NULL, inserts line element at head of list
 */
int list_ins_next(List *list, ListElmt *element, char *str);

/*
 * removes the list element after the the given list element location. If the list element location
 * is NULL, removes the head of the list
 */
int list_rem_next(List *list, ListElmt *element);

/* returns a pointer to the line element at the head of the list */
ListElmt *list_head(List *list);

/* returns the number of list elements within the list */
int list_size(List *list);

/* returns pointer to next line element within the list */
ListElmt *list_next(ListElmt *element);

/* prints list */
void list_display(List *list);

/**************************************************************************************************/


#endif

/**************************************************************************************************/

